@@ -80,11 +80,11 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   widgets["ip"] = spin;
   attach(*manage(spin), 2, 5, 1, 2, FILL|EXPAND, FILL);
   spin->signal_input().connect(
-        SigC::bind(SigC::slot(*this, &GUIIPv4Analyzer::map_ip_input), spin));
+        sigc::bind(sigc::mem_fun(*this, &GUIIPv4Analyzer::map_ip_input), spin));
   spin->signal_output().connect(
-        SigC::bind(SigC::slot(*this, &GUIIPv4Analyzer::map_ip_output), spin));
+        sigc::bind(sigc::mem_fun(*this, &GUIIPv4Analyzer::map_ip_output), spin));
   spin->signal_value_changed().connect(
-        SigC::slot(*this, &GUIIPv4Analyzer::on_ip_changed));
+        sigc::mem_fun(*this, &GUIIPv4Analyzer::on_ip_changed));
   
   spin = new SpinButton;
   spin->set_numeric(FALSE);
@@ -94,11 +94,11 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   widgets["mask"] = spin;
   attach(*manage(spin), 2, 5, 2, 3, FILL|EXPAND, FILL);
   spin->signal_input().connect(
-        SigC::bind(SigC::slot(*this, &GUIIPv4Analyzer::map_mask_input), spin));
+        sigc::bind(sigc::mem_fun(*this, &GUIIPv4Analyzer::map_mask_input), spin));
   spin->signal_output().connect(
-        SigC::bind(SigC::slot(*this, &GUIIPv4Analyzer::map_mask_output), spin));
+        sigc::bind(sigc::mem_fun(*this, &GUIIPv4Analyzer::map_mask_output), spin));
   spin->signal_value_changed().connect(
-        SigC::slot(*this, &GUIIPv4Analyzer::on_mask_changed));
+        sigc::mem_fun(*this, &GUIIPv4Analyzer::on_mask_changed));
   
   spin = new SpinButton;
   spin->set_range(0, 32);
@@ -106,7 +106,7 @@ GUIIPv4Analyzer::GUIIPv4Analyzer()
   widgets["pfxlen"] = spin;
   attach(*manage(spin), 2, 5, 3, 4, FILL|EXPAND, FILL);
   spin->signal_value_changed().connect(
-        SigC::slot(*this, &GUIIPv4Analyzer::on_pfxlen_changed));
+        sigc::mem_fun(*this, &GUIIPv4Analyzer::on_pfxlen_changed));
   
   // ****************** "Output" section ******************.
   // Add the "Range" hbox.
